@@ -20,7 +20,10 @@
 from neuron import h
 import numpy as np
 import os
-import tables
+try:
+    import tables
+except ImportError:
+    print "You will not able to save in HDF because you don't have pytables installed."
 import datetime
 import matplotlib
 import matplotlib.pyplot as plt
@@ -501,6 +504,13 @@ class Manager(object):
         self._load_geom(filename)
         self._load_allRef(filename)
         
+    def load_neuroml(self, filename):
+        """This loads neuroml, using the internal Neuron loader"""
+        h.load_file('celbild.hoc')
+        cb = h.CellBuild(0)
+        cb.manage.neuroml(filename)
+        logger.info(("File %s has been loaded. Check the output if any errors has occurred") %filename)
+        
     
     def _load_geom(self, filename):
         """Load the geometry of the model"""
